@@ -69,7 +69,7 @@ couchdb_document_set_property (GObject *object,
 	case PROP_DATABASE:
 		if (document->priv->database != NULL)
 			g_object_unref (G_OBJECT (document->priv->database));
-		document->priv->database = g_object_ref (G_OBJECT (g_value_get_object (value)));
+		document->priv->database = g_value_dup_object (value);
 		break;
 	default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -301,7 +301,7 @@ couchdb_document_remove_field (CouchdbDocument *document, const char *field)
  * be freed by calling #g_slist_free.
  */
 GSList *
-couchdb_document_get_fields (CouchdbDocument *document)
+couchdb_document_get_field_names (CouchdbDocument *document)
 {
 	GList *json_list;
 	GSList *result = NULL;
