@@ -139,7 +139,6 @@ couchdb_session_class_init (CouchdbSessionClass *klass)
 	object_class->finalize = couchdb_session_finalize;
 	object_class->set_property = couchdb_session_set_property;
 	object_class->get_property = couchdb_session_get_property;
-	klass->get_database = NULL;
 
 	g_object_class_install_property (object_class,
         	                         PROP_URI,
@@ -194,7 +193,7 @@ couchdb_session_init (CouchdbSession *session)
 	session->priv->credentials = NULL;
 
 #ifdef DEBUG_MESSAGES
-	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, debug_message, NULL);
+	g_log_set_handler ("Couchdb-GLib", G_LOG_LEVEL_DEBUG, debug_message, NULL);
 #endif
 }
 
@@ -312,8 +311,11 @@ couchdb_session_get_database_info (CouchdbSession *session, const char *dbname,
 							    json_object_get_int_member (object, "doc_count"),
 							    json_object_get_int_member (object, "doc_del_count"),
 							    json_object_get_int_member (object, "update_seq"),
+							    json_object_get_int_member (object, "purge_seq"),
 							    json_object_get_boolean_member (object, "compact_running"),
-							    json_object_get_int_member (object, "disk_size"));
+							    json_object_get_int_member (object, "disk_size"),
+							    json_object_get_int_member (object, "disk_format_version"),
+							    json_object_get_int_member (object, "instance_start_time"));
 		}
 	}
 	g_object_unref (G_OBJECT (parser));
@@ -341,12 +343,8 @@ couchdb_session_get_database (CouchdbSession *session, const char *dbname, GErro
 	g_return_val_if_fail (dbname != NULL, NULL);
 
 	dbinfo = couchdb_session_get_database_info (session, dbname, error);
-	if (dbinfo != NULL) {
-		if (COUCHDB_SESSION_GET_CLASS (session)->get_database != NULL)
-			return COUCHDB_SESSION_GET_CLASS (session)->get_database (session, dbname);
-		else
-			return couchdb_database_new (session, dbname);
-	}
+	if (dbinfo != NULL)
+		return couchdb_database_new (session, dbname);
 
 	return NULL;
 }
@@ -456,7 +454,7 @@ couchdb_session_compact_database (CouchdbSession *session, const char *dbname, G
 	url = g_strdup_printf ("%s/%s/_compact", couchdb_session_get_uri (session), dbname);
 	output = json_parser_new ();
 
-	if (couchdb_session_send_message (session, SOUP_METHOD_POST, url, NULL, output, error)) {
+	if (couchdb_session_send_message (session, SOUP_METHOD_POST, url, "", output, error)) {
 		JsonNode *root_node;
 
 		root_node = json_parser_get_root (output);
@@ -564,7 +562,9 @@ _session_authenticate(SoupSession *http_session, SoupMessage *msg,
 
 	if (retrying) {
 		g_signal_emit_by_name (session, COUCHDB_SIGNAL_AUTHENTICATION_FAILED, NULL);
+#ifdef DEBUG_MESSAGES
 		g_debug ("Authentication failed!");
+#endif
 		return FALSE;
 	}
 
@@ -666,7 +666,9 @@ parse_json_response (CouchdbSession *session, JsonParser *json_parser, SoupMessa
 	}
 
 	if (str && str->len > 0) {
+#ifdef DEBUG_MESSAGES
 		g_debug ("Response body: %s", str->str);
+#endif
 		if (!json_parser_load_from_data (json_parser,
 						 (const gchar *) str->str,
 						 str->len,
@@ -710,7 +712,7 @@ couchdb_session_send_message (CouchdbSession *session, const char *method, const
 	if (error != NULL)
 		real_error = error;
 	else
-		*real_error = NULL;
+		real_error = NULL;
 
 	http_message = soup_message_new (method, url);
 	if (body != NULL) {
@@ -728,8 +730,8 @@ couchdb_session_send_message (CouchdbSession *session, const char *method, const
 		}
 	}
 
-	g_debug ("Sending %s to %s... with headers\n: ", method, url);
 #ifdef DEBUG_MESSAGES
+	g_debug ("Sending %s to %s... with headers: ", method, url);
 	soup_message_headers_foreach (http_message->request_headers,
 				      (SoupMessageHeadersForeachFunc) debug_print_headers,
 				      NULL);
@@ -738,10 +740,14 @@ couchdb_session_send_message (CouchdbSession *session, const char *method, const
 	if (SOUP_STATUS_IS_SUCCESSFUL (status)) {
 		if (output != NULL)
 		       	parse_json_response (session, output, http_message, real_error);
+		g_object_unref (G_OBJECT (http_message));
+
 	       	return TRUE;
 	} else {
 		if (error != NULL)
 			g_set_error (error, COUCHDB_ERROR, status, "%s", http_message->reason_phrase);
+		g_object_unref (G_OBJECT (http_message));
+
 		return FALSE;
 	}
 }
@@ -761,7 +767,7 @@ debug_message (const gchar *log_domain, GLogLevelFlags log_level,
 
 	couchdb_env_debug_messages = g_getenv(COUCHDB_ENV_DEBUG_MESSAGES);
 	if (couchdb_env_debug_messages != NULL) {
-		g_printf ("couchdb-glib:DEBUG: %s\n", message);
+		g_print ("%s-DEBUG: %s\n", log_domain, message);
 	}
 }
 #endif
